pub enum ParseEvent {
BeforeElement,
AfterElement,
}Variants
BeforeElement
Event emitted when an element is discovered and its attributes are parsed, just before parsing its children.
AfterElement
Event emitted when an element is fully parsed, including its children.