parse

Function parse 

pub fn parse<P: AsRef<Path>>(file_path: P, data: &str) -> Result<Tree<'_>>
Parse an HTML file with templating expressions and statements and return an HTML tree containing references to the original data string.

If you want an owned version, use parse_owned.

This function is equivalent to Builder::new().parse(file_path, data).

Errors

This function returns an error if an HTML element is malformed or if an expression or a statement cannot be parsed.

See the module documentation.